# frozen_string_literal: true

require 'net/http'
require 'json'
require 'uri'
require 'erb'
require 'socket'
require 'digest'
require 'logger'

module Checkson
  class APIClient
    attr_reader :apiaddr, :outfile

    def initialize(apiaddr, outfile)
      @apiaddr = apiaddr
      @outfile = outfile
    end

    def getchecks
      template = <<-TEMPLATE
        <%@checks.each do |check| %>
        check '<%=check["description"]%>' do
          using <%=check["check"]%>
          <%check["sets"].each do |key,value| %>
          set :<%=key%>, "<%=value%>"
          <%end%>
        <%unless check["helps"].eql?(nil)%>
          <%check["helps"].each do |help| %>
          help '<%= help %>'
          <%end%>
        <%end%>
        end
        <% end %>
      TEMPLATE
      querydata = get
      @checks = querydata['checks'] if querydata['status'].eql? 'ok'
      begin
        remove_empty_lines(ERB.new(template).result(binding))
      rescue StandardError
        die querydata['error']
      end
    end

    def writechecks
      File.open(@outfile, 'w') do |f|
        f.write(getchecks)
      end
    end

    private

    def remove_empty_lines(string)
      regex = /^\s]$\n/
      string.gsub(regex, '')
    end

    def get
      token = ENV['CHECKSON_API_KEY']
      token ||= 'empty'
      hostname = Socket.gethostname
      query("#{keyhash(token)}/get/#{hostname}")
    end

    def query(command)
      @ep = "#{@apiaddr}/api/v1"
      route = "#{@ep}/#{command}"
      JSON.parse(Net::HTTP.get(URI.parse(route)))
    end

    def keyhash(token)
      Digest::SHA512.hexdigest(token)
    end

    def die(msg)
      warn(msg)
      exit 1
    end
  end
end
