# frozen_string_literal: true

module Checkson
  module Check
    class Certificate < Checkson::Check::Base
      def initialize(opts = {})
        @opts = (@opts || {}).merge(opts)
        @opts[:port] ||= 443
        super()
      end

      def check
        raise ArgumentError, 'No options given' unless @opts[:domain] && @opts[:port] || @opts[:certfile] || @opts[:leftdays]

        @opts[:domain] ? http_check : file_check
      end

      protected

      def cert_check(cert)
        time_left = @opts[:leftdays] * 86_400
        failed! if Time.now + time_left > cert.not_after
      end

      def file_check
        require 'openssl'
        begin
          raw = File.read @opts[:certfile] if File.file? @opts[:certfile]
          certificate = OpenSSL::X509::Certificate.new raw
          cert_check certificate
        rescue StandardError
          failed!
        end
      end

      def http_check
        require 'net/http'
        require 'openssl'

        uri = URI::HTTPS.build(host: @opts[:domain], port: @opts[:port])
        begin
          response = Net::HTTP.start(uri.host, uri.port, use_ssl: true)
          cert = response.peer_cert

          cert_check cert
        rescue StandardError
          failed!
        end
      end
    end
  end
end
