# frozen_string_literal: true

module Checkson
  module Check
    class DNS < Checkson::Check::Base
      def initialize(opts = {})
        @opts = { domain: 'heise.de',
                  timeout: 1,
                  host: 'localhost' }.merge(opts)
        super()
      end

      def check
        require 'resolv'
        resolver = Resolv::DNS.new(nameserver: [@opts[:host]])
        resolver.timeouts = @opts[:timeout]
        begin
          resolver.getaddress(@opts[:domain])
        rescue Resolv::ResolvTimeout
          failed!
          log("Resolving #{@opts[:domain]} timed out")
        rescue Resolv::ResolvError
          failed!
          log("Could not resolve #{@opts[:domain]}")
        end
      end
    end
  end
end
