# frozen_string_literal: true

require 'ipaddr'

module Checkson
  module Check
    class Process < Checkson::Check::Shell
      def initialize(opts = {})
        @opts = opts
        raise ArgumentError, 'Neither pidfile nor process name given' unless @opts[:pidfile] || @opts[:name]

        super()
      end

      def check
        @opts[:pidfile] ? check_pidfile : check_name
      end

      protected

      def check_pidfile
        pid = File.read(@opts[:pidfile]).strip
        execute("kill -0 #{pid} 2>&1")

        unless $?.exitstatus.zero?
          failed!
          log("Process ID #{pid} is not running")
        end
      rescue Errno::ENOENT
        failed!
        log("Cannot open pidfile: #{@opts[:pidfile]}")
      end

      def check_name
        ps = execute('ps auxwww')

        if @opts[:name].is_a?(Regexp) && ps !~ (@opts[:name])
          failed!
          log("No process found matching regular expression `#{@opts[:name].source}`")
        elsif !ps.include?(@opts[:name])
          failed!
          log("No process found matching name `#{@opts[:name]}`")
        end
      end
    end
  end
end
